# -*- coding: utf-8 -*-

CONFIG_ID_ERROR = 'The "config_id" parameter must be given!'
CONFIG_ID_NOT_FOUND_ERROR = 'The given "config_id" named "%s" was not found!'
IN_NAME_OF_UNAUTHORIZED = (
    'User must be Manager/MeetingManager to use "in_name_of=%s" option!'
)
ANNEXES_FILTER_VALUES = [
    "to_print", "confidential", "publishable", "to_sign", "signed"]
